<?php
/**
 * Lawyer Lite functions and definitions
 *
 * @package lawyer-lite
 */
/**
 * Set the content width based on the theme's design and stylesheet.
 */
 
/* Theme Setup */
if ( ! function_exists( 'lawyer_lite_setup' ) ) :

function lawyer_lite_setup() {
	
	$GLOBALS['content_width'] = apply_filters( 'lawyer_lite_content_width', 640 );

	load_theme_textdomain( 'lawyer-lite', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 250,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
	) );

	add_image_size('lawyer-lite-homepage-thumb',250,145,true);
    register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'lawyer-lite' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );
	
	add_editor_style( array( 'css/editor-style.css', lawyer_lite_font_url() ) );
}

endif;
add_action( 'after_setup_theme', 'lawyer_lite_setup' );

/* Theme Widgets Setup */
function lawyer_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'lawyer-lite' ),
		'description'   => __( 'Appears on blog page sidebar', 'lawyer-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'lawyer-lite' ),
		'description'   => __( 'Appears on page sidebar', 'lawyer-lite' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'lawyer-lite' ),
		'description'   => __( 'Appears on page sidebar', 'lawyer-lite' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'lawyer-lite' ),
		'description'   => __( 'Appears on footer', 'lawyer-lite' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'lawyer-lite' ),
		'description'   => __( 'Appears on footer', 'lawyer-lite' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'lawyer-lite' ),
		'description'   => __( 'Appears on footer', 'lawyer-lite' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'lawyer-lite' ),
		'description'   => __( 'Appears on footer', 'lawyer-lite' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

add_action( 'widgets_init', 'lawyer_lite_widgets_init' );

/* Theme Font URL */
function lawyer_lite_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Vollkorn:400,400i,600,600i,700,700i,900,900i';
	$font_family[] = 'Montserrat:100,200i,300,300i,400,400i,500,500i,700i,800,900,900i';
	
	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}	

/* Theme enqueue scripts */

function lawyer_lite_scripts() {
	wp_enqueue_style( 'lawyer-lite-font', lawyer_lite_font_url(), array() );
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'lawyer-lite-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'lawyer-lite-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_script( 'SmoothScroll-jquery', get_template_directory_uri() . '/js/SmoothScroll.js', array('jquery') );
	wp_enqueue_script( 'lawyer-lite-custom-scripts-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'bootstrap-jquery', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );

	wp_enqueue_style('lawyer-lite-ie', get_template_directory_uri().'/css/ie.css', array('lawyer-lite-basic-style'));
	wp_style_add_data( 'lawyer-lite-ie', 'conditional', 'IE' );
}
add_action( 'wp_enqueue_scripts', 'lawyer_lite_scripts' );

/*radio button sanitization*/
 function lawyer_lite_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

define('LAWYER_LITE_CREDIT','https://www.themeshopy.com/','lawyer-lite');

if ( ! function_exists( 'lawyer_lite_credit' ) ) {
	function lawyer_lite_credit(){
		echo "<a href=".esc_url(LAWYER_LITE_CREDIT)." target='_blank'>".esc_html__('ThemeShopy','lawyer-lite')."</a>";
	}
}

/* Custom header additions. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';